==> zalando-kubectl-1.12.7.69.tar.gz: zalando-kubectl-1.12.7.69/zalando_kubectl/models/deployment.py <==
import json
import subprocess

from zalando_kubectl.models.stack import Stack


class DeploymentUpdateError(Exception):
    pass


class Deployment:
    def __init__(self, kubectl, name, namespace):
        self.kubectl = kubectl
        self.name = name
        self.namespace = namespace

    def _spec(self):
        command = [self.kubectl, 'get', 'deployment']
        if self.namespace:
            command.extend(['-n', self.namespace])
        command.extend([self.name, '-o', 'json'])
        output = subprocess.check_output(command, stderr=subprocess.DEVNULL)
        return json.loads(output)

    def ss_ref(self):
        try:
            deployment = self._spec()
        except subprocess.CalledProcessError:
            raise RuntimeError('Failed to get deployment spec {}'.format(self.name))
        if 'ownerReferences' not in deployment['metadata']:
            return None
        for r in deployment['metadata']['ownerReferences']:
            if r['kind'] == 'Stack':
                return r
        return None

    def get_stackset(self):
        ref = self.ss_ref()
        return Stack(self.kubectl, ref['name'], self.namespace)

    def annotate_restart(self, restart_id):
        patch = [{'op': 'add', 'path': '/spec/template/metadata/annotations', 'value': {'restart': restart_id}}]
        command = [self.kubectl, 'patch', 'deployment', self.name, '--type', 'json', '--patch', json.dumps(patch)]
        if self.namespace:
            command.extend(['-n', self.namespace])
        try:
            subprocess.check_call(command, stdout=subprocess.DEVNULL, stdin=subprocess.DEVNULL)
        except subprocess.CalledProcessError as e:
            raise DeploymentUpdateError('Failed to annotate deployment: %s'.format(e.stderr))

==> zalando-kubectl-1.14.7.88.tar.gz: zalando-kubectl-1.14.7.88/zalando_kubectl/models/deployment.py <==
import json
import subprocess

from zalando_kubectl.models.stack import Stack
from zalando_kubectl.utils import ExternalBinary


class DeploymentUpdateError(Exception):
    pass


class Deployment:
    def __init__(self, kubectl: ExternalBinary, name: str):
        self.kubectl = kubectl
        self.name = name

    def _spec(self):
        command = ("get", "deployment", self.name, '-o', 'json')
        output = self.kubectl.run(command, stderr=subprocess.DEVNULL, stdout=subprocess.PIPE, check=True).stdout
        return json.loads(output.decode('utf-8'))

    def ss_ref(self):
        try:
            deployment = self._spec()
        except subprocess.CalledProcessError:
            raise RuntimeError('Failed to get deployment spec {}'.format(self.name))
        if 'ownerReferences' not in deployment['metadata']:
            return None
        for r in deployment['metadata']['ownerReferences']:
            if r['kind'] == 'Stack':
                return r
        return None

    def get_stackset(self):
        ref = self.ss_ref()
        return Stack(self.kubectl, ref['name'])

    def annotate_restart(self, restart_id):
        patch = [{'op': 'add', 'path': '/spec/template/metadata/annotations', 'value': {'restart': restart_id}}]
        command = ('patch', 'deployment', self.name, '--type', 'json', '--patch', json.dumps(patch))
        try:
            self.kubectl.run(command, stdout=subprocess.DEVNULL, stdin=subprocess.DEVNULL, check=True)
        except subprocess.CalledProcessError as e:
            raise DeploymentUpdateError('Failed to annotate deployment: %s'.format(e.stderr))
